<!--
SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

## Component Test Case: Generic_Branch

Test case for validation of the generic_branch component for symmetrical power flow calculations.

The circuit diagram is as follows:
```
source_4--node_1--genric_branch_3--node_2--load_5                                                                              
```
